==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter.md <==
# AwsAppMeshVirtualRouter


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')
```



| Illustration | AwsAppMeshVirtualRouter | AwsAppMeshVirtualRouterCard | AwsAppMeshVirtualRouterGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter.png) | ![illustration for AwsAppMeshVirtualRouter](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter.Local.png) | ![illustration for AwsAppMeshVirtualRouterCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouterCard.Local.png) | ![illustration for AwsAppMeshVirtualRouterGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouterGroup.Local.png) |




## AwsAppMeshVirtualRouter

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouter
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouter('AwsAppMeshVirtualRouter', 'Aws App Mesh Virtual Router', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouter
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouter('AwsAppMeshVirtualRouter', 'Aws App Mesh Virtual Router', 'an optional tech label')
@enduml
```

## AwsAppMeshVirtualRouterCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouterCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouterCard('AwsAppMeshVirtualRouterCard', 'Aws App Mesh Virtual Router Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouterCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouterCard('AwsAppMeshVirtualRouterCard', 'Aws App Mesh Virtual Router Card', 'an optional description')
@enduml
```

## AwsAppMeshVirtualRouterGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouterGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouterGroup('AwsAppMeshVirtualRouterGroup', 'Aws App Mesh Virtual Router Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouterGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouterGroup('AwsAppMeshVirtualRouterGroup', 'Aws App Mesh Virtual Router Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter.md <==
# AwsAppMeshVirtualRouter


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')
```



| Illustration | AwsAppMeshVirtualRouter | AwsAppMeshVirtualRouterCard | AwsAppMeshVirtualRouterGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter.png) | ![illustration for AwsAppMeshVirtualRouter](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter.Local.png) | ![illustration for AwsAppMeshVirtualRouterCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouterCard.Local.png) | ![illustration for AwsAppMeshVirtualRouterGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouterGroup.Local.png) |




## AwsAppMeshVirtualRouter

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouter
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouter('AwsAppMeshVirtualRouter', 'Aws App Mesh Virtual Router', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouter
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouter('AwsAppMeshVirtualRouter', 'Aws App Mesh Virtual Router', 'an optional tech label')
@enduml
```

## AwsAppMeshVirtualRouterCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouterCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouterCard('AwsAppMeshVirtualRouterCard', 'Aws App Mesh Virtual Router Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouterCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouterCard('AwsAppMeshVirtualRouterCard', 'Aws App Mesh Virtual Router Card', 'an optional description')
@enduml
```

## AwsAppMeshVirtualRouterGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouterGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouterGroup('AwsAppMeshVirtualRouterGroup', 'Aws App Mesh Virtual Router Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsAppMeshVirtualRouterGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsAppMeshVirtualRouter')

' renders the element
AwsAppMeshVirtualRouterGroup('AwsAppMeshVirtualRouterGroup', 'Aws App Mesh Virtual Router Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
